# sequence
Manage sequences of frame numbers

## Install

```bash
pip install --upgrade cioseq
```

## Usage
```
s = Sequence.create("1-10, 14, 20-50x4")
```

## Test

```
python -m unittest discover -v -s ./tests  -p 'test_*.py'
```

## Contributing

Pull requests welcome. 

## License
[MIT](LICENSE)
